@@ -13,15 +13,19 @@ fn main() {
         std::process::exit(0);
     }
 
-    // link to c++ std library dylib as the c++ library depends on it
-    println!("cargo:rustc-flags=-l dylib=stdc++");
+    // link to c++ std library as the c++ library depends on it
+    if std::env::var("CARGO_FEATURE_STDCPP_STATIC_LINK").is_ok() {
+        // statically link as requested
+        println!("cargo:rustc-link-lib=static=stdc++");
+    } else {
+        // default path: dynamically link
+        println!("cargo:rustc-flags=-l dylib=stdc++");
+    }
 
-    // 0. To guess at if we're on the right platform, look for linux as the system & arm as the architecture
-    // Note I'm checking HOST instead of TARGET since the C++ library depends on natively linking to some libraries
-    //   that are only on rpis
-    let host = std::env::var("HOST").unwrap();
-    if !(host.contains("arm") || host.contains("aarch")) || !host.contains("linux") {
-        eprintln!("rpi-led-matrix-sys detected you're likely not compiling on a raspberry pi");
+    // 0. To guess at if we're targetting the right platform, look for linux as the system & arm as the architecture
+    let target = std::env::var("TARGET").unwrap();
+    if !(target.contains("arm") || target.contains("aarch")) || !target.contains("linux") {
+        eprintln!("rpi-led-matrix-sys detected you're likely not compiling for a raspberry pi");
         std::process::exit(-1);
     }
 
@@ -37,17 +41,15 @@ fn main() {
         .status()
         .expect("git status failed")
         .success()
-    {
-        if !Command::new("git")
+        && !Command::new("git")
             .arg("submodule")
             .arg("update")
             .arg("--init")
             .status()
             .expect("process failed to execute")
             .success()
-        {
-            println!("cargo:warning=failed to checkout/update the C++ library git submodule");
-        }
+    {
+        println!("cargo:warning=failed to checkout/update the C++ library git submodule");
     }
 
     // delete our output git directory, if it exists, then copy the git repo over
@@ -64,9 +66,7 @@ fn main() {
     let status = Command::new("make")
         .status()
         .expect("process failed to execute");
-    if !status.success() {
-        panic!("failed to compile the C++ library");
-    }
+    assert!(status.success(), "failed to compile the C++ library");
 
     // 2.1 rename the library produced to avoid ambiguity with global variants.
     let cpp_lib_lib_out_file: std::path::PathBuf =
